import { useCallback, useMemo, useRef, useState } from 'react';
export const useWsApi = (wsApiUrl, route) => {
    const [error, setError] = useState(false);
    const [connected, setConnected] = useState(false);
    const webSocket = useRef();
    const sendRequest = useCallback((request) => {
        if (!route)
            throw 'Not route';
        if (!webSocket.current)
            throw 'Not connected';
        webSocket.current.send(JSON.stringify({
            action: route.action,
            ...request,
        }));
    }, [route]);
    const disconnect = useCallback(() => webSocket.current?.close(), [webSocket]);
    const connection = useMemo(() => {
        return {
            disconnect,
            sendRequest,
        };
    }, [disconnect, sendRequest]);
    const connect = useCallback(async (options) => {
        return new Promise((resolve) => {
            if (webSocket.current && (webSocket.current.readyState === WebSocket.CONNECTING || webSocket.current.readyState === WebSocket.OPEN))
                throw 'Already connected';
            webSocket.current = new WebSocket(wsApiUrl);
            webSocket.current.onopen = () => {
                setConnected(true);
                setError(false);
                options?.onConnected?.(connection);
                resolve();
            };
            webSocket.current.onmessage = (ev) => {
                if (!ev.data || ev.data === '{}')
                    return;
                setError(false);
                options?.onResponse?.(JSON.parse(ev.data), connection);
            };
            webSocket.current.onerror = (error) => {
                setError(false);
                options?.onError?.(error, connection);
            };
            webSocket.current.onclose = () => {
                setConnected(false);
                options?.onDisconnected?.();
                webSocket.current = undefined;
            };
        });
    }, [wsApiUrl, connection]);
    return {
        connect,
        connected,
        connection,
        error,
        disconnect,
    };
};
//# sourceMappingURL=useWsApi.js.map